from .utils import function
from .utils.function import fnx
from .nonlinear.bracketing.graph import graph
from .nonlinear.bracketing.bisection import bisection
from .nonlinear.bracketing.regulafalsi import regulafalsi